<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>ką tik</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 nauja žinutė</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>prieš %1 min.</translation>
    </message>
</context>
</TS>